package com.bytedesk.bytedesk_push;

import androidx.annotation.NonNull;

import io.flutter.embedding.engine.plugins.FlutterPlugin;
import io.flutter.plugin.common.MethodCall;
import io.flutter.plugin.common.MethodChannel;
import io.flutter.plugin.common.MethodChannel.MethodCallHandler;
import io.flutter.plugin.common.MethodChannel.Result;
import io.flutter.plugin.common.PluginRegistry.Registrar;

import com.xiaomi.mipush.sdk.MiPushClient;
import com.orhanobut.logger.Logger;
import com.orhanobut.logger.AndroidLogAdapter;

import android.app.ActivityManager;
import android.app.ActivityManager.RunningAppProcessInfo;
import android.app.Application;
import android.content.Context;
import android.os.Process;

import java.util.List;

/** BytedeskPushPlugin */
public class BytedeskPushPlugin implements FlutterPlugin, MethodCallHandler {
  /// The MethodChannel that will the communication between Flutter and native Android
  ///
  /// This local reference serves to register the plugin with the Flutter Engine and unregister it
  /// when the Flutter Engine is detached from the Activity
  private MethodChannel channel;
  private static volatile Context context;

  public static Context getContext() {
    return BytedeskPushPlugin.context;
  }

  public static void setContext(Context context) {
    BytedeskPushPlugin.context = context;
  }

  @Override
  public void onAttachedToEngine(@NonNull FlutterPluginBinding flutterPluginBinding) {
    channel = new MethodChannel(flutterPluginBinding.getBinaryMessenger(), "bytedesk_push");
    channel.setMethodCallHandler(this);
    BytedeskPushPlugin.setContext(flutterPluginBinding.getApplicationContext());
  }

  @Override
  public void onMethodCall(@NonNull MethodCall call, @NonNull Result result) {
    //
    if (call.method.equals("xmRegisterPush")) {
      Logger.addLogAdapter(new AndroidLogAdapter());
      // 注册
      String appId = call.argument("appId");
      String appKey = call.argument("appKey");
      xmRegisterPush(appId, appKey);

    } else if (call.method.equals("xmSetUserAccount")) {
      // 设置账号
      String userAccount = call.argument("userAccount");
      xmSetUserAccount(userAccount);

    } else if (call.method.equals("getPlatformVersion")) {
      result.success("Android " + android.os.Build.VERSION.RELEASE);
    } else {
      result.notImplemented();
    }
  }

  @Override
  public void onDetachedFromEngine(@NonNull FlutterPluginBinding binding) {
    channel.setMethodCallHandler(null);
  }

  //
  public void xmRegisterPush(String appId, String appKey) {
    if (shouldInit()) {
      Logger.d("appId %s, appKey %s", appId, appKey);
      MiPushClient.registerPush(context, appId, appKey);
    }
  }

  //
  public void xmSetUserAccount(String userAccount) {
    Logger.d("userAccount: %s", userAccount);
    MiPushClient.setUserAccount(context, userAccount, null);
  }

  private boolean shouldInit() {
    ActivityManager am = ((ActivityManager) context.getSystemService(Context.ACTIVITY_SERVICE));
    List<RunningAppProcessInfo> processInfos = am.getRunningAppProcesses();
    String mainProcessName = context.getPackageName();
    int myPid = Process.myPid();
    for (RunningAppProcessInfo info : processInfos) {
      if (info.pid == myPid && mainProcessName.equals(info.processName)) {
        return true;
      }
    }
    return false;
    // return true;
  }

}
